/*
 * Javolution - Java(TM) Solution for Real-Time and Embedded Systems
 * Copyright (C) 2005 - Javolution (http://javolution.org/)
 * All rights reserved.
 * 
 * Permission to use, copy, modify, and distribute this software is
 * freely granted, provided that this notice is preserved.
 */
package javolution.lang;

/**
 * <p> This interfaces identifies mutable objects capable of being used again
 *     or repeatedly without incurring dynamic memory allocation.</p>
 *     
 * <p> Instances of this class can safely reside in permanent memory (e.g.<code>
 *     static</code>) or be an integral part of a higher level component.
 *     Once {@link #reset reset}, reusable objects behave as if they were
 *     brand-new.</p>   
 * 
 * <p> Note: Reusable objects can be allocated on the stack (using an 
 *     {@link javolution.realtime.ObjectFactory ObjectFactory}) providing that
 *     the factory cleanup method calls the {@link #reset reset} method.
 *     For example:<pre>
 *     static final ObjectFactory MY_REUSABLE_FACTORY = new ObjectFactory() {
 *         public Object create() {
 *             return new MyReusable();
 *         }
 *         public void cleanup(Object obj) {
 *             ((MyReusable)obj).reset();
 *         }
 *     };</pre></p>
 *        
 * @author  <a href="mailto:jean-marie@dautelle.com">Jean-Marie Dautelle</a>
 * @version 2.2, January 8, 2004
 */
public interface Reusable {

    /**
     * Resets the internal state of this object to its default values.
     */
    void reset();

}